#!/usr/bin/env python
# encoding: utf-8

#    magma - Readout and create Magma lists. 
# 
#    Copyright © 2008 Arne Babenhauserheide
# 
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>


"""
Returns a magma-list containing the file name. Takes the names as input.
"""
# Get the sha1_berechnen module. 
from sha1_berechnen import sha1_berechnen
# And get the yaml dumper and loader
from yaml import dump, load

class Magma: 
    def __init__(self, inputfilenames): 
        self.filenames = inputfilenames
        self.sha1 = {}
        for i in self.filenames: 
            self.sha1[i] = sha1_berechnen(i)
        self.magma = self.magma()
        self.data = load(self.magma)
        
    def magma(self): 
        magma = {}
        list_of_magnets = []
        for i in self.filenames: 
            magnet = {}
            magnet['hash'] = {}
            magnet['hash']['sha1'] = self.sha1[i]
            magnet['name'] = i
            list_of_magnets.append(magnet)
        magma['files'] = list_of_magnets
        return "#MAGMAv0.4\n" + dump(magma, default_flow_style=False)

#### Self-Test ####
if __name__ == '__main__': 
    from sys import argv
    if len(argv) > 1: 
        filenames = argv[1:]
    else: 
        # filename = "magma_liste_erzeugen.py"
        filenames = [raw_input("Dateiname und Pfad eingeben: ")]
        gnutella_client_ip = raw_input("Eigene IP oder dyndns-Adresse eingeben: ")
    magma = Magma(filenames)
    print magma.magma
    



#!/usr/bin/env python
# encoding: utf-8
"""Readout a file and calculate the sha1-hash. Output it base32 encoded. """ 

#### Background ####

__author__ = 'Arne Babenhauserheide <arne_bab ät web punkt de>'
__copyright__ = 'Copyright (C) 2007 Arne Babenhauserheide'
__date__ = '2007-07-06'
__licence__ = 'GPL-2 or later'
__program__ = 'sha1 aus Datei berechnen'
__version__ = '0.1'
__depends__ = 'hashlib, base64'

#### Background ####

#### Imports ####

# We need the sha1-hashing function from haslib
from hashlib import sha1

# and for encoding the hash we need the base32 encoding function from base64
from base64 import b32encode

#### Imports ####

def sha1_berechnen(filename): 
    """Calculate the sha1-hash and output it base32 encoded as it is required by magnetlinks. Takes the filename as input"""
    # First we create 
    #: The file-object
    try: 
        file = open(filename, "r")
    except: 
        print "Error when reading file"
        return Null
    # Then we get 
    #: A line of data readout from the file. 
    dataline = file.readline()
    # so we can calculate arbitrary large files without running out of memory (as long as the lines aren't too long). # TODO: don't calculate by line, but by a fixed amount of bytes. 
    
    # Next we call in
    #: The sha1-function
    sha = sha1()
    
    # into which we can then route the data, line by line
    # while the dataline isn't empty (\n aka linebreak is not empty)
    # We put the datalines into sha1. 
    while dataline != "": 
        sha.update(dataline)
	# And get the next dataline
	dataline = file.readline()
    
    # Via digest, this function can then output
    # the sha1 hash as bytes. 
    # we put it through bb32encode() to generate
    #: The base32 encoded sha1-hash
    xt_sha1 = b32encode(sha.digest())
    
    # At last return the base32 encoded sha1 hash of the file. 
    return xt_sha1

#### User-Input ####

# This sample input just calculates the sha1-hash of the script itself. 

filename = "sha1_berechnen.py" 
# filename = raw_input("Dateiname und Pfad eingeben: ")

#### User-Input ####

#### Self-Test ####

# If the script is called directly 
# and given a commandline argument, 
# parse that file. 

if __name__ == "__main__": 
    from sys import argv
    if len(argv) < 2: 
        print sha1_berechnen(filename)
    else: 
        print sha1_berechnen(argv[1])

### Self-Test ####



#!/usr/bin/env python
# encoding: utf-8

#    magma - Readout and create Magma lists. 
# 
#    Copyright © 2008 Arne Babenhauserheide
# 
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>


"""Magma - Readout and create Magma lists. 

Magma lists are lists of files which can be downloaded via magnet links. 

They are written in yaml format to be easily readable as well as flexible and powerful. 

It depends on U{pyyaml <http://pyyaml.org/>}. 

An example magma file is I{example-0.4.magma}. 

This API documentation is avaible from U{http://gnuticles.gnufu.net/pymagma/}, and the code is avaible from a U{Mercurial repository <http://freehg.org/u/ArneBab/magma/>}. """

from setuptools import setup, find_packages
from magma.__init__ import __doc__ as magma__doc__

# Create the desription from the docstrings 

DESCRIPTION = __doc__.split("\n")[0]

LONG_DESCRIPTION = "\n".join(__doc__.split("\n")[1:])

LONG_DESCRIPTION += "\n\n" + magma__doc__

setup(name='magma',
      version='0.1',
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION, 
      author='Arne Babenhauserheide',
      author_email='arne_bab@web.de',
      keywords=["magma", "yaml", "p2p", "magnet"], 
      license="GNU GPL-3 or later", 
      platforms=["any"], 
      install_requires = ["pyyaml"], 
      packages = find_packages('.'), 
      url='http://freehg.org/u/ArneBab/magma',
      py_modules=["magma" , "magma/*"],
      scripts=["magma/magma_list.py"]
     )
